CBaseAnimating

Struct CBaseAnimating 

#[repr(C)]
pub struct CBaseAnimating {
Show 88 fields pub base: CBaseEntity, pub m_bCanUseFastPathFromServer: bool, pub gap_9e1: [c_char; 3], pub m_flGroundSpeed: f32, pub m_flLastEventCheck: f32, pub m_nForceBone: i32, pub m_vecForce: Vector3, pub m_nSkin: i32, pub m_nBody: i32, pub m_camoIndex: i32, pub m_decalIndex: i32, pub m_nHitboxSet: i32, pub m_flModelScale: f32, pub m_nRagdollImpactFXTableId: i32, pub m_flSkyScaleStartTime: f32, pub m_flSkyScaleEndTime: f32, pub m_flSkyScaleStartValue: f32, pub m_flSkyScaleEndValue: f32, pub m_SequenceTransitioner: [c_char; 376], pub m_flIKGroundContactTime: f32, pub m_flIKGroundMinHeight: f32, pub m_flIKGroundMaxHeight: f32, pub m_flEstIkFloor: f32, pub m_flEstIkOffset: f32, pub gap_bb4: [c_char; 4], pub m_pIk: *mut c_void, pub m_ikPrevSequence: i32, pub m_bSequenceFinished: bool, pub m_bSequenceLooped: bool, pub m_bSequenceLoops: bool, pub gap_bc7: [c_char; 1], pub m_numSequenceLoops: i32, pub m_continueAnimatingAfterRagdoll: bool, pub m_useLockedAnimDeltaYaw: bool, pub gap_bce: [c_char; 2], pub m_lockedAnimDeltaYaw: f32, pub m_threadedBoneSetup: bool, pub m_settingUpBones: bool, pub gap_bd6: [c_char; 2], pub m_flDissolveStartTime: f32, pub m_baseAnimatingActivity: i32, pub m_flPoseParameter: [f32; 11], pub m_poseParameterOverTimeActive: bool, pub gap_c0d: [c_char; 3], pub m_poseParameterGoalValue: [f32; 11], pub m_poseParameterEndTime: [f32; 11], pub m_lastTimeSetPoseParametersSameAs: f32, pub m_bClientSideAnimation: bool, pub m_bReallyClientSideAnimation: bool, pub gap_c6e: [c_char; 2], pub m_nNewSequenceParity: i32, pub m_nResetEventsParity: i32, pub m_boneCacheHandle: i64, pub m_fBoneCacheFlags: i16, pub gap_c82: [c_char; 2], pub m_animNetworkFlags: i32, pub m_animActive: bool, pub m_animCollisionEnabled: bool, pub m_animInitialCorrection: bool, pub m_animWaitingForCleanup: bool, pub m_animWaitingForCleanupTime: i32, pub m_recordedAnim: i64, pub m_recordedAnimIndex: i32, pub m_recordedAnimCachedFrameIndex: i32, pub m_recordedAnimPlaybackRate: f32, pub m_recordedAnimPlaybackTime: f32, pub m_recordedAnimTransform: matrix3x4_t, pub m_recordedAnimPlaybackEnt: EHandle, pub m_recordedAnimBlendTime: f32, pub m_recordedAnimBlendOffset: Vector3, pub m_recordedAnimBlendAngles: Vector3, pub m_animRelativeData: AnimRelativeData, pub m_syncingWithEntity: EHandle, pub gap_d7c: [c_char; 4], pub m_predictedAnimEventData: PredictedAnimEventData, pub m_animRefEntityAttachmentIndex: i32, pub m_fireAttachmentSmartAmmoIndex: i32, pub m_fireAttachmentChestFocusIndex: i32, pub m_fireAttachmentModelIndex: i32, pub m_keyHitboxes: [c_char; 160], pub m_pStudioHdr: *mut c_void, pub m_animSequence: i32, pub m_animCycle: f32, pub m_animModelIndex: i32, pub m_animStartTime: f32, pub m_animStartCycle: f32, pub m_animPlaybackRate: f32, pub m_animFrozen: bool,
}

Fields

base: CBaseEntitym_bCanUseFastPathFromServer: boolgap_9e1: [c_char; 3]m_flGroundSpeed: f32m_flLastEventCheck: f32m_nForceBone: i32m_vecForce: Vector3m_nSkin: i32m_nBody: i32m_camoIndex: i32m_decalIndex: i32m_nHitboxSet: i32m_flModelScale: f32m_nRagdollImpactFXTableId: i32m_flSkyScaleStartTime: f32m_flSkyScaleEndTime: f32m_flSkyScaleStartValue: f32m_flSkyScaleEndValue: f32m_SequenceTransitioner: [c_char; 376]m_flIKGroundContactTime: f32m_flIKGroundMinHeight: f32m_flIKGroundMaxHeight: f32m_flEstIkFloor: f32m_flEstIkOffset: f32gap_bb4: [c_char; 4]m_pIk: *mut c_voidm_ikPrevSequence: i32m_bSequenceFinished: boolm_bSequenceLooped: boolm_bSequenceLoops: boolgap_bc7: [c_char; 1]m_numSequenceLoops: i32m_continueAnimatingAfterRagdoll: boolm_useLockedAnimDeltaYaw: boolgap_bce: [c_char; 2]m_lockedAnimDeltaYaw: f32m_threadedBoneSetup: boolm_settingUpBones: boolgap_bd6: [c_char; 2]m_flDissolveStartTime: f32m_baseAnimatingActivity: i32m_flPoseParameter: [f32; 11]m_poseParameterOverTimeActive: boolgap_c0d: [c_char; 3]m_poseParameterGoalValue: [f32; 11]m_poseParameterEndTime: [f32; 11]m_lastTimeSetPoseParametersSameAs: f32m_bClientSideAnimation: boolm_bReallyClientSideAnimation: boolgap_c6e: [c_char; 2]m_nNewSequenceParity: i32m_nResetEventsParity: i32m_boneCacheHandle: i64m_fBoneCacheFlags: i16gap_c82: [c_char; 2]m_animNetworkFlags: i32m_animActive: boolm_animCollisionEnabled: boolm_animInitialCorrection: boolm_animWaitingForCleanup: boolm_animWaitingForCleanupTime: i32m_recordedAnim: i64m_recordedAnimIndex: i32m_recordedAnimCachedFrameIndex: i32m_recordedAnimPlaybackRate: f32m_recordedAnimPlaybackTime: f32m_recordedAnimTransform: matrix3x4_tm_recordedAnimPlaybackEnt: EHandlem_recordedAnimBlendTime: f32m_recordedAnimBlendOffset: Vector3m_recordedAnimBlendAngles: Vector3m_animRelativeData: AnimRelativeDatam_syncingWithEntity: EHandlegap_d7c: [c_char; 4]m_predictedAnimEventData: PredictedAnimEventDatam_animRefEntityAttachmentIndex: i32m_fireAttachmentSmartAmmoIndex: i32m_fireAttachmentChestFocusIndex: i32m_fireAttachmentModelIndex: i32m_keyHitboxes: [c_char; 160]m_pStudioHdr: *mut c_voidm_animSequence: i32m_animCycle: f32m_animModelIndex: i32m_animStartTime: f32m_animStartCycle: f32m_animPlaybackRate: f32m_animFrozen: bool

Methods from Deref<Target = CBaseEntity>

pub unsafe fn some_get_origin_varient_02( &self, vector: *mut Vector3, ) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn some_get_origin_varient_01( &self, vector: *mut Vector3, ) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn eye_angles(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_angles(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_eye_position(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_center_position(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_origin(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_forward_vector( &self, vector: *mut Vector3, unk1: *const c_void, unk2: *const c_void, )

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works