CBaseEntity

Struct CBaseEntity 

#[repr(C)]
pub struct CBaseEntity {
Show 210 fields pub vftable: *const c_void, pub m_RefEHandle: EHandle, pub gap_c: [c_char; 4], pub m_collideable: *mut c_void, pub m_networkable: *mut c_void, pub genericKeyValueCount: i32, pub gap_24: [c_char; 4], pub genericKeyValues: *mut c_void, pub m_pfnMoveDone: *mut c_void, pub m_pfnThink: *mut c_void, pub m_Network: CServerNetworkProperty, pub m_entIndex: i32, pub gap_6c: [c_char; 4], pub m_iClassname: i64, pub m_flAnimTime: f32, pub m_flSimulationTime: f32, pub m_creationTick: i32, pub m_nLastThinkTick: i32, pub m_PredictableID: i32, pub touchStamp: i32, pub m_aThinkFunctions: [c_char; 32], pub m_entitySpawnTime: f32, pub m_spawner: EHandle, pub m_scriptClass: i32, pub m_wantsDamageCallbacks: bool, pub m_wantsDeathCallbacks: bool, pub gap_be: [c_char; 2], pub m_nNextThinkTick: i32, pub m_fEffects: i32, pub m_ModelName: i64, pub m_target: i64, pub m_networkedFlags: i32, pub m_nRenderFX: c_char, pub m_nRenderMode: c_char, pub m_nModelIndex: i16, pub m_clrRender: Color, pub m_desiredHibernationType: i32, pub m_scriptMinHibernationType: i32, pub m_minSelfAndDescendantHibernationType: i32, pub m_actualHibernationType: i32, pub m_hibernationQueueIndex: i32, pub m_bRenderWithViewModels: bool, pub gap_f9: [c_char; 3], pub m_nameVisibilityFlags: i32, pub m_cloakEndTime: f32, pub m_cloakFadeInEndTime: f32, pub m_cloakFadeOutStartTime: f32, pub m_cloakFadeInDuration: f32, pub m_cloakFlickerAmount: f32, pub m_cloakFlickerEndTime: f32, pub m_cloakFadeOutDuration: f32, pub m_highlightIsNetworked: bool, pub gap_11d: [c_char; 3], pub m_highlightParams: [Vector3; 16], pub m_highlightFunctionBits: [i32; 8], pub m_highlightPlayerVisibilityBits: [i32; 8], pub m_highlightServerFadeBases: [f32; 2], pub m_highlightServerFadeStartTimes: [f32; 2], pub m_highlightServerFadeEndTimes: [f32; 2], pub m_highlightServerContextID: i32, pub m_highlightTeamBits: i32, pub m_nextGrenadeTargetTime: f32, pub m_grenadeTargetDebounce: f32, pub m_nSimulationTick: i32, pub m_fDataObjectTypes: i32, pub m_nextVelocitySample: f32, pub m_velocitySamples: [Vector3; 5], pub m_iEFlags: i64, pub m_fFlags: i32, pub gap_29c: [c_char; 4], pub m_iName: i64, pub m_scriptNameIndex: i32, pub m_instanceNameIndex: i32, pub m_scriptName: [c_char; 64], pub m_instanceName: [c_char; 64], pub m_holdUsePrompt: i64, pub m_pressUsePrompt: i64, pub m_attachmentLerpStartTime: f32, pub m_attachmentLerpEndTime: f32, pub m_attachmentLerpStartOrigin: Vector3, pub m_attachmentLerpStartAngles: Vector3, pub m_parentAttachmentType: i32, pub m_parentAttachmentIndex: i32, pub m_parentAttachmentHitbox: i32, pub m_parentAttachmentModel: i32, pub m_MoveType: c_char, pub m_MoveCollide: c_char, pub gap_372: [c_char; 2], pub m_RestoreMoveTypeOnDetach: i32, pub m_hMoveParent: EHandle, pub m_hMoveChild: EHandle, pub m_hMovePeer: EHandle, pub m_bIsActiveChild: bool, pub m_bPrevAbsOriginValid: bool, pub gap_386: [c_char; 2], pub m_Collision: CCollisionProperty, pub m_hOwnerEntity: EHandle, pub m_CollisionGroup: i32, pub m_contents: i32, pub m_baseSolidType: i32, pub m_pPhysicsObject: *mut c_void, pub m_flNavIgnoreUntilTime: f32, pub m_hGroundEntity: EHandle, pub m_flGroundChangeTime: f32, pub m_vecBaseVelocity: Vector3, pub m_vecAbsVelocity: Vector3, pub m_vecAngVelocity: Vector3, pub m_rgflCoordinateFrame: [f32; 12], pub m_flFriction: f32, pub m_flLocalTime: f32, pub m_flVPhysicsUpdateLocalTime: f32, pub m_flMoveDoneTime: f32, pub m_nPushEnumCount: i32, pub m_vecPrevAbsOrigin: Vector3, pub m_vecAbsOrigin: Vector3, pub m_angAbsRotation: Vector3, pub m_vecVelocity: Vector3, pub m_pBlocker: EHandle, pub m_iGlobalname: i64, pub m_iParent: i64, pub m_iHammerID: i32, pub m_flSpeed: f32, pub m_iMaxHealth: i32, pub m_iHealth: i32, pub m_pfnTouch: *mut c_void, pub m_pfnUse: *mut c_void, pub m_pfnBlocked: *mut c_void, pub m_bClientSideRagdoll: bool, pub m_lifeState: c_char, pub m_forceVisibleInPhaseShift: bool, pub m_baseTakeDamage: c_char, pub m_invulnerableToDamageCount: i32, pub m_passDamageToParent: c_char, pub gap_4f9: [c_char; 3], pub m_deathVelocity: Vector3, pub m_lastTitanFootstepDamageTime: f32, pub m_flMaxspeed: f32, pub m_visibilityFlags: i32, pub m_scriptVisible: bool, pub gap_515: [c_char; 3], pub m_OnUser1: [c_char; 40], pub m_OnDeath: [c_char; 40], pub m_OnDestroy: [c_char; 40], pub m_cellwidth: i32, pub m_cellbits: i32, pub m_cellX: i32, pub m_cellY: i32, pub m_cellZ: i32, pub m_localOrigin: Vector3, pub m_localAngles: Vector3, pub m_vecViewOffset: Vector3, pub m_ListByClass: i32, pub gap_5cc: [c_char; 4], pub m_pPrevByClass: *mut c_void, pub m_pNextByClass: *mut c_void, pub m_iInitialTeamNum: i32, pub m_iTeamNum: i32, pub m_passThroughFlags: i32, pub m_passThroughThickness: i32, pub m_passThroughDirection: f32, pub m_spawnflags: i32, pub m_AIAddOn: i64, pub m_flGravity: f32, pub m_entityFadeDist: f32, pub m_dissolveEffectEntityHandle: EHandle, pub m_fadeDist: f32, pub m_iSignifierName: i64, pub m_collectedInvalidateFlags: i32, pub m_collectingInvalidateFlags: bool, pub gap_61d: [c_char; 3], pub m_lagCompensationCounter: i32, pub m_bLagCompensate: bool, pub m_bNetworkQuantizeOriginAndAngles: bool, pub m_bForcePurgeFixedupStrings: bool, pub gap_627: [c_char; 1], pub m_pEvent: *mut c_void, pub m_debugOverlays: i32, pub gap_634: [c_char; 4], pub m_pTimedOverlay: *mut c_void, pub m_ScriptScope: [c_char; 32], pub m_hScriptInstance: i64, pub m_iszScriptId: i64, pub m_bossPlayer: EHandle, pub m_usableType: i32, pub m_usablePriority: i32, pub m_usableRadius: f32, pub m_usableFOV: f32, pub m_usePromptSize: f32, pub m_hasDispatchedSpawn: bool, pub m_bDoDestroyCallback: bool, pub m_bDoPreSpawnCallback: bool, pub m_bDoOnSpawnedCallback: bool, pub m_spottedBeginTimes: [f32; 31], pub m_spottedLatestTimes: [f32; 31], pub m_spottedByTeams: i32, pub m_minimapData: [c_char; 40], pub m_shieldHealth: i32, pub m_shieldHealthMax: i32, pub m_areEntityLinksNetworked: bool, pub gap_7b9: [c_char; 3], pub m_entitiesLinkedFromMeCount: i32, pub m_entitiesLinkedToMeCount: i32, pub m_entitiesLinkedFromMe: [EHandle; 64], pub m_entitiesLinkedToMe: [EHandle; 64], pub m_pusherWithChildrenRadius: f32, pub m_childPusherMoveHandlerCount: i32, pub gap_9cc: [c_char; 4], pub m_statusEffectPlugin: *mut CBaseEntity, pub gap_9d8: [c_char; 1], pub m_physDummyMotionEnabled: bool,
}

Fields

vftable: *const c_voidm_RefEHandle: EHandlegap_c: [c_char; 4]m_collideable: *mut c_voidm_networkable: *mut c_voidgenericKeyValueCount: i32gap_24: [c_char; 4]genericKeyValues: *mut c_voidm_pfnMoveDone: *mut c_voidm_pfnThink: *mut c_voidm_Network: CServerNetworkPropertym_entIndex: i32gap_6c: [c_char; 4]m_iClassname: i64m_flAnimTime: f32m_flSimulationTime: f32m_creationTick: i32m_nLastThinkTick: i32m_PredictableID: i32touchStamp: i32m_aThinkFunctions: [c_char; 32]m_entitySpawnTime: f32m_spawner: EHandlem_scriptClass: i32m_wantsDamageCallbacks: boolm_wantsDeathCallbacks: boolgap_be: [c_char; 2]m_nNextThinkTick: i32m_fEffects: i32m_ModelName: i64m_target: i64m_networkedFlags: i32m_nRenderFX: c_charm_nRenderMode: c_charm_nModelIndex: i16m_clrRender: Colorm_desiredHibernationType: i32m_scriptMinHibernationType: i32m_minSelfAndDescendantHibernationType: i32m_actualHibernationType: i32m_hibernationQueueIndex: i32m_bRenderWithViewModels: boolgap_f9: [c_char; 3]m_nameVisibilityFlags: i32m_cloakEndTime: f32m_cloakFadeInEndTime: f32m_cloakFadeOutStartTime: f32m_cloakFadeInDuration: f32m_cloakFlickerAmount: f32m_cloakFlickerEndTime: f32m_cloakFadeOutDuration: f32m_highlightIsNetworked: boolgap_11d: [c_char; 3]m_highlightParams: [Vector3; 16]m_highlightFunctionBits: [i32; 8]m_highlightPlayerVisibilityBits: [i32; 8]m_highlightServerFadeBases: [f32; 2]m_highlightServerFadeStartTimes: [f32; 2]m_highlightServerFadeEndTimes: [f32; 2]m_highlightServerContextID: i32m_highlightTeamBits: i32m_nextGrenadeTargetTime: f32m_grenadeTargetDebounce: f32m_nSimulationTick: i32m_fDataObjectTypes: i32m_nextVelocitySample: f32m_velocitySamples: [Vector3; 5]m_iEFlags: i64m_fFlags: i32gap_29c: [c_char; 4]m_iName: i64m_scriptNameIndex: i32m_instanceNameIndex: i32m_scriptName: [c_char; 64]m_instanceName: [c_char; 64]m_holdUsePrompt: i64m_pressUsePrompt: i64m_attachmentLerpStartTime: f32m_attachmentLerpEndTime: f32m_attachmentLerpStartOrigin: Vector3m_attachmentLerpStartAngles: Vector3m_parentAttachmentType: i32m_parentAttachmentIndex: i32m_parentAttachmentHitbox: i32m_parentAttachmentModel: i32m_MoveType: c_charm_MoveCollide: c_chargap_372: [c_char; 2]m_RestoreMoveTypeOnDetach: i32m_hMoveParent: EHandlem_hMoveChild: EHandlem_hMovePeer: EHandlem_bIsActiveChild: boolm_bPrevAbsOriginValid: boolgap_386: [c_char; 2]m_Collision: CCollisionPropertym_hOwnerEntity: EHandlem_CollisionGroup: i32m_contents: i32m_baseSolidType: i32m_pPhysicsObject: *mut c_voidm_flNavIgnoreUntilTime: f32m_hGroundEntity: EHandlem_flGroundChangeTime: f32m_vecBaseVelocity: Vector3m_vecAbsVelocity: Vector3m_vecAngVelocity: Vector3m_rgflCoordinateFrame: [f32; 12]m_flFriction: f32m_flLocalTime: f32m_flVPhysicsUpdateLocalTime: f32m_flMoveDoneTime: f32m_nPushEnumCount: i32m_vecPrevAbsOrigin: Vector3m_vecAbsOrigin: Vector3m_angAbsRotation: Vector3m_vecVelocity: Vector3m_pBlocker: EHandlem_iGlobalname: i64m_iParent: i64m_iHammerID: i32m_flSpeed: f32m_iMaxHealth: i32m_iHealth: i32m_pfnTouch: *mut c_voidm_pfnUse: *mut c_voidm_pfnBlocked: *mut c_voidm_bClientSideRagdoll: boolm_lifeState: c_charm_forceVisibleInPhaseShift: boolm_baseTakeDamage: c_charm_invulnerableToDamageCount: i32m_passDamageToParent: c_chargap_4f9: [c_char; 3]m_deathVelocity: Vector3m_lastTitanFootstepDamageTime: f32m_flMaxspeed: f32m_visibilityFlags: i32m_scriptVisible: boolgap_515: [c_char; 3]m_OnUser1: [c_char; 40]m_OnDeath: [c_char; 40]m_OnDestroy: [c_char; 40]m_cellwidth: i32m_cellbits: i32m_cellX: i32m_cellY: i32m_cellZ: i32m_localOrigin: Vector3m_localAngles: Vector3m_vecViewOffset: Vector3m_ListByClass: i32gap_5cc: [c_char; 4]m_pPrevByClass: *mut c_voidm_pNextByClass: *mut c_voidm_iInitialTeamNum: i32m_iTeamNum: i32m_passThroughFlags: i32m_passThroughThickness: i32m_passThroughDirection: f32m_spawnflags: i32m_AIAddOn: i64m_flGravity: f32m_entityFadeDist: f32m_dissolveEffectEntityHandle: EHandlem_fadeDist: f32m_iSignifierName: i64m_collectedInvalidateFlags: i32m_collectingInvalidateFlags: boolgap_61d: [c_char; 3]m_lagCompensationCounter: i32m_bLagCompensate: boolm_bNetworkQuantizeOriginAndAngles: boolm_bForcePurgeFixedupStrings: boolgap_627: [c_char; 1]m_pEvent: *mut c_voidm_debugOverlays: i32gap_634: [c_char; 4]m_pTimedOverlay: *mut c_voidm_ScriptScope: [c_char; 32]m_hScriptInstance: i64m_iszScriptId: i64m_bossPlayer: EHandlem_usableType: i32m_usablePriority: i32m_usableRadius: f32m_usableFOV: f32m_usePromptSize: f32m_hasDispatchedSpawn: boolm_bDoDestroyCallback: boolm_bDoPreSpawnCallback: boolm_bDoOnSpawnedCallback: boolm_spottedBeginTimes: [f32; 31]m_spottedLatestTimes: [f32; 31]m_spottedByTeams: i32m_minimapData: [c_char; 40]m_shieldHealth: i32m_shieldHealthMax: i32m_areEntityLinksNetworked: boolgap_7b9: [c_char; 3]m_entitiesLinkedFromMeCount: i32m_entitiesLinkedToMeCount: i32m_entitiesLinkedFromMe: [EHandle; 64]m_entitiesLinkedToMe: [EHandle; 64]m_pusherWithChildrenRadius: f32m_childPusherMoveHandlerCount: i32gap_9cc: [c_char; 4]m_statusEffectPlugin: *mut CBaseEntitygap_9d8: [c_char; 1]m_physDummyMotionEnabled: bool

Implementations

Source

impl CBaseEntity

pub unsafe fn some_get_origin_varient_02( &self, vector: *mut Vector3, ) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn some_get_origin_varient_01( &self, vector: *mut Vector3, ) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn eye_angles(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_angles(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_eye_position(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_center_position(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_origin(&self, vector: *mut Vector3) -> *mut Vector3

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works

pub unsafe fn get_forward_vector( &self, vector: *mut Vector3, unk1: *const c_void, unk2: *const c_void, )

Safety

this is a wrapper to a vtable function

calling this function without knowing how it works may or may create ub this is a auto doc so idk how it works