RawCVar

Struct RawCVar 

pub struct RawCVar { /* private fields */ }

Implementations

Source

impl RawCVar

auto generated docs; idk how to make macros capture docs so no docs :(

Safety

idk

pub unsafe fn find_command_base( &self, command_name: *const c_char, ) -> *mut ConCommandBase

auto generated docs; idk how to make macros capture docs so no docs :(

Safety

idk

pub unsafe fn find_convar(&self, convar_name: *const c_char) -> *mut ConVar

auto generated docs; idk how to make macros capture docs so no docs :(

Safety

idk

pub unsafe fn find_concommand( &self, concommand_name: *const c_char, ) -> *mut ConCommand

auto generated docs; idk how to make macros capture docs so no docs :(

Safety

idk

pub unsafe fn get_cvar_raw_interator(&self) -> *const RawCvarIterator

auto generated docs; idk how to make macros capture docs so no docs :(

Safety

idk