Module errors

Module errors 

Errors produced by rrplug that can be returned to the user

Enums

CStringPtrError
Handles errors when trying to convert a c_char pointer to &str
CVarQueryError
Errors that may happen when querying a cvar
CallError
Errors created by calls to sqvm functions
CompletionError
errors that can happen when using completion feature of concommands
FsOpenError
errors that happen when acquiring external interfaces from a pointer or dll name
InterfaceGetterError
errors that happen when acquiring external interfaces from a pointer or dll name
RegisterError
Errors that may happen during the registration process of anything
SQCompileError
Errors from compiling a buffer on the sqvm
SQFunctionRegistrationError
errors that happen when acquiring external interfaces from a pointer or dll name