pub struct SquirrelFn<'a, T: IntoSquirrelArgs> { /* private fields */ }Expand description
provides invariance for calling squirrel functions with little overhead
Implementations
Sourceimpl<'a, T: IntoSquirrelArgs> SquirrelFn<'a, T>
impl<'a, T: IntoSquirrelArgs> SquirrelFn<'a, T>
Sourcepub const unsafe fn new_unchecked(obj: SQHandle<'a, SQClosure>) -> Self
pub const unsafe fn new_unchecked(obj: SQHandle<'a, SQClosure>) -> Self
creates a new SquirrelFn using the invariance of SQHandle<SQClosure>
Safety
doesn’t check if the function passed has the correct args and return type
Sourcepub fn run(
&mut self,
sqvm: NonNull<HSquirrelVM>,
sqfunctions: &'static SquirrelFunctions,
args: T,
) -> Result<(), CallError>
pub fn run( &mut self, sqvm: NonNull<HSquirrelVM>, sqfunctions: &'static SquirrelFunctions, args: T, ) -> Result<(), CallError>
calls the underlying squirrel function on the provided sqvm
Errors
This function will return an error if the fails to execute for some reason which is unlikely since it would be type checked
Sourcepub fn call(
&mut self,
sqvm: NonNull<HSquirrelVM>,
sqfunctions: &'static SquirrelFunctions,
args: T,
) -> Result<(), CallError>
pub fn call( &mut self, sqvm: NonNull<HSquirrelVM>, sqfunctions: &'static SquirrelFunctions, args: T, ) -> Result<(), CallError>
calls the underlying squirrel function on the provided sqvm
Errors
This function will return an error if the fails to execute for some reason which is unlikely since it would be type checked