SQVMName

Derive Macro SQVMName 

#[derive(SQVMName)]
macro to auto generate a SQVMName implementation

the implementation will just be the name of the struct/enum so if the squirrel name is diffrent use a util macro in rrplug::macro::utils