Module squirrel

Module squirrel 

thin wrappers around squirrel functions

some can produce exepections which cannot be caught

good reference for some functions : objecthandling

Structs

SQFuncInfo
holds infomation about a sq function for it to be registered corretly
SQFunctionContext
the contexts for which the squirrel function would be registered
SqFunctions
functions that are used to interact with the sqvm

Statics

SQFUNCTIONS
functions that used to interact with the sqvm
SQVM_CLIENT
the client sqvm
SQVM_SERVER
the server sqvm
SQVM_UI
the ui sqvm

Functions

get_sq_array
gets a array of T at a stack pos
get_sq_bool
gets a bool at a stack pos
get_sq_float
gets a float at a stack pos
get_sq_function_object
gets a function SQObject from the sqvm
get_sq_int
gets a int at a stack pos
get_sq_object
gets the SQObject at a stack pos
get_sq_string
gets a string at a stack pos
get_sq_vector
gets a vector at a stack pos
push_sq_array
pushes a Vec<T> to the sqvm
push_sq_bool
pushes a bool to the sqvm
push_sq_float
pushes a f32 to the sqvm
push_sq_int
pushes a i32 to the sqvm
push_sq_object
pushes a SQObject to the sqvm
push_sq_string
pushes a T: Into<String> to the sqvm
push_sq_vector
pushes a Vector3 to the sqvm
sqvm_to_context
returns the context of the sqvm

Type Aliases

FuncSQFuncInfo
function type which is used in register_sq_functions to get SQFuncInfo