pub struct RawCVar { /* private fields */ }Implementations
Sourceimpl RawCVar
auto generated docs; idk how to make macros capture docs so no docs :(
impl RawCVar
auto generated docs; idk how to make macros capture docs so no docs :(
Safety
idk
Sourcepub unsafe fn find_command_base(
&self,
command_name: *const c_char,
) -> *mut ConCommandBase
pub unsafe fn find_command_base( &self, command_name: *const c_char, ) -> *mut ConCommandBase
Sourcepub unsafe fn find_concommand(
&self,
concommand_name: *const c_char,
) -> *mut ConCommand
pub unsafe fn find_concommand( &self, concommand_name: *const c_char, ) -> *mut ConCommand
Sourcepub unsafe fn get_cvar_raw_interator(&self) -> *const RawCvarIterator
pub unsafe fn get_cvar_raw_interator(&self) -> *const RawCvarIterator