Errors produced by rrplug that can be returned to the user
Enums
- CString
PtrError - Handles errors when trying to convert a c_char pointer to
&str - CVar
Query Error - Errors that may happen when querying a cvar
- Call
Error - Errors created by calls to sqvm functions
- Completion
Error - errors that can happen when using completion feature of concommands
- FsOpen
Error - errors that happen when acquiring external interfaces from a pointer or dll name
- Interface
Getter Error - errors that happen when acquiring external interfaces from a pointer or dll name
- Register
Error - Errors that may happen during the registration process of anything
- SQCompile
Error - Errors from compiling a buffer on the sqvm
- SQFunction
Registration Error - errors that happen when acquiring external interfaces from a pointer or dll name