SquirrelFn

Struct SquirrelFn 

pub struct SquirrelFn<'a, T: IntoSquirrelArgs> { /* private fields */ }
provides invariance for calling squirrel functions with little overhead

Implementations

Source

impl<'a, T: IntoSquirrelArgs> SquirrelFn<'a, T>

pub const unsafe fn new_unchecked(obj: SQHandle<'a, SQClosure>) -> Self

creates a new SquirrelFn using the invariance of SQHandle<SQClosure>

Safety

doesn’t check if the function passed has the correct args and return type

pub fn run( &mut self, sqvm: NonNull<HSquirrelVM>, sqfunctions: &'static SquirrelFunctions, args: T, ) -> Result<(), CallError>

calls the underlying squirrel function on the provided sqvm

Errors

This function will return an error if the fails to execute for some reason which is unlikely since it would be type checked

pub fn call( &mut self, sqvm: NonNull<HSquirrelVM>, sqfunctions: &'static SquirrelFunctions, args: T, ) -> Result<(), CallError>

calls the underlying squirrel function on the provided sqvm

Errors

This function will return an error if the fails to execute for some reason which is unlikely since it would be type checked