pub struct UserData<T, const OVERWRITE: bool = false, const VALUE: u64 = 0>(/* private fields */);Expand description
UserData is used to push user provided data to the sqvm for storage
UserDataRef can be used to access the data from functions calls
UserData handles dropping the data via a release hook in sqvm
Implementations
Sourceimpl<const OVERWRITE: bool, const VALUE: u64, T: 'static> UserData<T, OVERWRITE, VALUE>
impl<const OVERWRITE: bool, const VALUE: u64, T: 'static> UserData<T, OVERWRITE, VALUE>
Sourcepub fn new(userdata: T) -> Self
pub fn new(userdata: T) -> Self
Creates a new UserData<T>.
Example
// cannot be pushed to sqvm normally
struct HttpClient;
#[rrplug::sqfunction(VM = "SERVER | CLIENT | UI")]
fn build_client() -> UserData<HttpClient> {
UserData::new(HttpClient)
}Sourcepub const fn from_boxed(userdata: Box<T>) -> Self
pub const fn from_boxed(userdata: Box<T>) -> Self
Creates a new UserData<T> from boxed data