thin wrappers around squirrel functions
some can produce exepections which cannot be caught
good reference for some functions : objecthandling
Structs
- SQFunc
Info - holds infomation about a sq function for it to be registered corretly
- SQFunction
Context - the contexts for which the squirrel function would be registered
- SqFunctions
- functions that are used to interact with the sqvm
Statics
- SQFUNCTIONS
- functions that used to interact with the sqvm
- SQVM_
CLIENT - the client sqvm
- SQVM_
SERVER - the server sqvm
- SQVM_UI
- the ui sqvm
Functions
- get_
sq_ array - gets a array of T at a stack pos
- get_
sq_ bool - gets a bool at a stack pos
- get_
sq_ float - gets a float at a stack pos
- get_
sq_ function_ object - gets a function
SQObjectfrom the sqvm - get_
sq_ int - gets a int at a stack pos
- get_
sq_ object - gets the
SQObjectat a stack pos - get_
sq_ string - gets a string at a stack pos
- get_
sq_ vector - gets a vector at a stack pos
- push_
sq_ array - pushes a
Vec<T>to the sqvm - push_
sq_ bool - pushes a
boolto the sqvm - push_
sq_ float - pushes a
f32to the sqvm - push_
sq_ int - pushes a
i32to the sqvm - push_
sq_ object - pushes a
SQObjectto the sqvm - push_
sq_ string - pushes a
T: Into<String>to the sqvm - push_
sq_ vector - pushes a
Vector3to the sqvm - sqvm_
to_ ⚠context - returns the context of the sqvm
Type Aliases
- FuncSQ
Func Info - function type which is used in
register_sq_functionsto getSQFuncInfo